@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
@@ -100,38 +102,38 @@ class DiscoverConnectionProfileRequest(proto.Message):
             This field is a member of `oneof`_ ``data_object``.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    connection_profile = proto.Field(
+    connection_profile: datastream_resources.ConnectionProfile = proto.Field(
         proto.MESSAGE,
         number=200,
         oneof="target",
         message=datastream_resources.ConnectionProfile,
     )
-    connection_profile_name = proto.Field(
+    connection_profile_name: str = proto.Field(
         proto.STRING,
         number=201,
         oneof="target",
     )
-    recursive = proto.Field(
+    recursive: bool = proto.Field(
         proto.BOOL,
         number=3,
         oneof="depth",
     )
-    recursion_depth = proto.Field(
+    recursion_depth: int = proto.Field(
         proto.INT32,
         number=4,
         oneof="depth",
     )
-    oracle_rdbms = proto.Field(
+    oracle_rdbms: datastream_resources.OracleRdbms = proto.Field(
         proto.MESSAGE,
         number=100,
         oneof="data_object",
         message=datastream_resources.OracleRdbms,
     )
-    mysql_rdbms = proto.Field(
+    mysql_rdbms: datastream_resources.MysqlRdbms = proto.Field(
         proto.MESSAGE,
         number=101,
         oneof="data_object",
@@ -160,13 +162,13 @@ class DiscoverConnectionProfileResponse(proto.Message):
             This field is a member of `oneof`_ ``data_object``.
     """
 
-    oracle_rdbms = proto.Field(
+    oracle_rdbms: datastream_resources.OracleRdbms = proto.Field(
         proto.MESSAGE,
         number=100,
         oneof="data_object",
         message=datastream_resources.OracleRdbms,
     )
-    mysql_rdbms = proto.Field(
+    mysql_rdbms: datastream_resources.MysqlRdbms = proto.Field(
         proto.MESSAGE,
         number=101,
         oneof="data_object",
@@ -189,15 +191,15 @@ class FetchStaticIpsRequest(proto.Message):
             call. will likely not be specified.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -207,7 +209,7 @@ class FetchStaticIpsResponse(proto.Message):
     r"""Response message for a 'FetchStaticIps' response.
 
     Attributes:
-        static_ips (Sequence[str]):
+        static_ips (MutableSequence[str]):
             list of static ips by account
         next_page_token (str):
             A token that can be sent as ``page_token`` to retrieve the
@@ -219,11 +221,11 @@ class FetchStaticIpsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    static_ips = proto.RepeatedField(
+    static_ips: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=1,
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -238,7 +240,7 @@ class FetchErrorsRequest(proto.Message):
             fetch any errors.
     """
 
-    stream = proto.Field(
+    stream: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -248,11 +250,11 @@ class FetchErrorsResponse(proto.Message):
     r"""Response message for a 'FetchErrors' response.
 
     Attributes:
-        errors (Sequence[google.cloud.datastream_v1alpha1.types.Error]):
+        errors (MutableSequence[google.cloud.datastream_v1alpha1.types.Error]):
             The list of errors on the Stream.
     """
 
-    errors = proto.RepeatedField(
+    errors: MutableSequence[datastream_resources.Error] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=datastream_resources.Error,
@@ -285,23 +287,23 @@ class ListConnectionProfilesRequest(proto.Message):
             Order by fields for the result.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    filter = proto.Field(
+    filter: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    order_by = proto.Field(
+    order_by: str = proto.Field(
         proto.STRING,
         number=5,
     )
@@ -311,13 +313,13 @@ class ListConnectionProfilesResponse(proto.Message):
     r"""
 
     Attributes:
-        connection_profiles (Sequence[google.cloud.datastream_v1alpha1.types.ConnectionProfile]):
+        connection_profiles (MutableSequence[google.cloud.datastream_v1alpha1.types.ConnectionProfile]):
             List of connection profiles.
         next_page_token (str):
             A token, which can be sent as ``page_token`` to retrieve the
             next page. If this field is omitted, there are no subsequent
             pages.
-        unreachable (Sequence[str]):
+        unreachable (MutableSequence[str]):
             Locations that could not be reached.
     """
 
@@ -325,16 +327,18 @@ class ListConnectionProfilesResponse(proto.Message):
     def raw_page(self):
         return self
 
-    connection_profiles = proto.RepeatedField(
+    connection_profiles: MutableSequence[
+        datastream_resources.ConnectionProfile
+    ] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=datastream_resources.ConnectionProfile,
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    unreachable = proto.RepeatedField(
+    unreachable: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=3,
     )
@@ -349,7 +353,7 @@ class GetConnectionProfileRequest(proto.Message):
             resource to get.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -387,20 +391,20 @@ class CreateConnectionProfileRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    connection_profile_id = proto.Field(
+    connection_profile_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    connection_profile = proto.Field(
+    connection_profile: datastream_resources.ConnectionProfile = proto.Field(
         proto.MESSAGE,
         number=3,
         message=datastream_resources.ConnectionProfile,
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=4,
     )
@@ -439,17 +443,17 @@ class UpdateConnectionProfileRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    update_mask = proto.Field(
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
         proto.MESSAGE,
         number=1,
         message=field_mask_pb2.FieldMask,
     )
-    connection_profile = proto.Field(
+    connection_profile: datastream_resources.ConnectionProfile = proto.Field(
         proto.MESSAGE,
         number=2,
         message=datastream_resources.ConnectionProfile,
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -482,11 +486,11 @@ class DeleteConnectionProfileRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -517,23 +521,23 @@ class ListStreamsRequest(proto.Message):
             Order by fields for the result.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    filter = proto.Field(
+    filter: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    order_by = proto.Field(
+    order_by: str = proto.Field(
         proto.STRING,
         number=5,
     )
@@ -543,13 +547,13 @@ class ListStreamsResponse(proto.Message):
     r"""
 
     Attributes:
-        streams (Sequence[google.cloud.datastream_v1alpha1.types.Stream]):
+        streams (MutableSequence[google.cloud.datastream_v1alpha1.types.Stream]):
             List of streams
         next_page_token (str):
             A token, which can be sent as ``page_token`` to retrieve the
             next page. If this field is omitted, there are no subsequent
             pages.
-        unreachable (Sequence[str]):
+        unreachable (MutableSequence[str]):
             Locations that could not be reached.
     """
 
@@ -557,16 +561,16 @@ class ListStreamsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    streams = proto.RepeatedField(
+    streams: MutableSequence[datastream_resources.Stream] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=datastream_resources.Stream,
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    unreachable = proto.RepeatedField(
+    unreachable: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=3,
     )
@@ -581,7 +585,7 @@ class GetStreamRequest(proto.Message):
             get.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -624,28 +628,28 @@ class CreateStreamRequest(proto.Message):
             validating it.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    stream_id = proto.Field(
+    stream_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    stream = proto.Field(
+    stream: datastream_resources.Stream = proto.Field(
         proto.MESSAGE,
         number=3,
         message=datastream_resources.Stream,
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    validate_only = proto.Field(
+    validate_only: bool = proto.Field(
         proto.BOOL,
         number=5,
     )
-    force = proto.Field(
+    force: bool = proto.Field(
         proto.BOOL,
         number=6,
     )
@@ -691,25 +695,25 @@ class UpdateStreamRequest(proto.Message):
             validating it.
     """
 
-    update_mask = proto.Field(
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
         proto.MESSAGE,
         number=1,
         message=field_mask_pb2.FieldMask,
     )
-    stream = proto.Field(
+    stream: datastream_resources.Stream = proto.Field(
         proto.MESSAGE,
         number=2,
         message=datastream_resources.Stream,
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    validate_only = proto.Field(
+    validate_only: bool = proto.Field(
         proto.BOOL,
         number=4,
     )
-    force = proto.Field(
+    force: bool = proto.Field(
         proto.BOOL,
         number=5,
     )
@@ -742,11 +746,11 @@ class DeleteStreamRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -785,37 +789,37 @@ class OperationMetadata(proto.Message):
             if there are any.
     """
 
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=1,
         message=timestamp_pb2.Timestamp,
     )
-    end_time = proto.Field(
+    end_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=2,
         message=timestamp_pb2.Timestamp,
     )
-    target = proto.Field(
+    target: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    verb = proto.Field(
+    verb: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    status_message = proto.Field(
+    status_message: str = proto.Field(
         proto.STRING,
         number=5,
     )
-    requested_cancellation = proto.Field(
+    requested_cancellation: bool = proto.Field(
         proto.BOOL,
         number=6,
     )
-    api_version = proto.Field(
+    api_version: str = proto.Field(
         proto.STRING,
         number=7,
     )
-    validation_result = proto.Field(
+    validation_result: datastream_resources.ValidationResult = proto.Field(
         proto.MESSAGE,
         number=8,
         message=datastream_resources.ValidationResult,
@@ -855,20 +859,20 @@ class CreatePrivateConnectionRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    private_connection_id = proto.Field(
+    private_connection_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    private_connection = proto.Field(
+    private_connection: datastream_resources.PrivateConnection = proto.Field(
         proto.MESSAGE,
         number=3,
         message=datastream_resources.PrivateConnection,
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=4,
     )
@@ -901,23 +905,23 @@ class ListPrivateConnectionsRequest(proto.Message):
             Order by fields for the result.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    filter = proto.Field(
+    filter: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    order_by = proto.Field(
+    order_by: str = proto.Field(
         proto.STRING,
         number=5,
     )
@@ -927,13 +931,13 @@ class ListPrivateConnectionsResponse(proto.Message):
     r"""
 
     Attributes:
-        private_connections (Sequence[google.cloud.datastream_v1alpha1.types.PrivateConnection]):
+        private_connections (MutableSequence[google.cloud.datastream_v1alpha1.types.PrivateConnection]):
             List of private connectivity configurations.
         next_page_token (str):
             A token, which can be sent as ``page_token`` to retrieve the
             next page. If this field is omitted, there are no subsequent
             pages.
-        unreachable (Sequence[str]):
+        unreachable (MutableSequence[str]):
             Locations that could not be reached.
     """
 
@@ -941,16 +945,18 @@ class ListPrivateConnectionsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    private_connections = proto.RepeatedField(
+    private_connections: MutableSequence[
+        datastream_resources.PrivateConnection
+    ] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=datastream_resources.PrivateConnection,
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    unreachable = proto.RepeatedField(
+    unreachable: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=3,
     )
@@ -987,15 +993,15 @@ class DeletePrivateConnectionRequest(proto.Message):
             be deleted.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    force = proto.Field(
+    force: bool = proto.Field(
         proto.BOOL,
         number=3,
     )
@@ -1010,7 +1016,7 @@ class GetPrivateConnectionRequest(proto.Message):
             connectivity configuration to get.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -1047,20 +1053,20 @@ class CreateRouteRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    route_id = proto.Field(
+    route_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    route = proto.Field(
+    route: datastream_resources.Route = proto.Field(
         proto.MESSAGE,
         number=3,
         message=datastream_resources.Route,
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=4,
     )
@@ -1092,23 +1098,23 @@ class ListRoutesRequest(proto.Message):
             Order by fields for the result.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    filter = proto.Field(
+    filter: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    order_by = proto.Field(
+    order_by: str = proto.Field(
         proto.STRING,
         number=5,
     )
@@ -1118,13 +1124,13 @@ class ListRoutesResponse(proto.Message):
     r"""route list response
 
     Attributes:
-        routes (Sequence[google.cloud.datastream_v1alpha1.types.Route]):
+        routes (MutableSequence[google.cloud.datastream_v1alpha1.types.Route]):
             List of Routes.
         next_page_token (str):
             A token, which can be sent as ``page_token`` to retrieve the
             next page. If this field is omitted, there are no subsequent
             pages.
-        unreachable (Sequence[str]):
+        unreachable (MutableSequence[str]):
             Locations that could not be reached.
     """
 
@@ -1132,16 +1138,16 @@ class ListRoutesResponse(proto.Message):
     def raw_page(self):
         return self
 
-    routes = proto.RepeatedField(
+    routes: MutableSequence[datastream_resources.Route] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message=datastream_resources.Route,
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    unreachable = proto.RepeatedField(
+    unreachable: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=3,
     )
@@ -1174,11 +1180,11 @@ class DeleteRouteRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -1193,7 +1199,7 @@ class GetRouteRequest(proto.Message):
             get.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
